.. :changelog:

History
-------

Unreleased
++++++++++++++++++

* Nothing yet

0.4.1 (2019-12-22)
++++++++++++++++++

* Fix classifiers

0.4.0 (2019-12-22)
++++++++++++++++++

* Add Django 2.2 support
* Add django CMS 3.6, 3.7 support
* Drop Django < 1.11 support
* Drop django CMS < 3.6 support
* Fix monkey-patch not applied consistently

0.3.0 (2018-01-15)
++++++++++++++++++

* Add support for multisite setups
* Add Django 1.11 support
* Add django CMS 3.5 support

0.2.0 (2016-12-04)
++++++++++++++++++

* Add support for multisite setups
* Add Django 1.9, 1.10 support
* Add django CMS 3.4 support

0.1.2 (2015-12-22)
++++++++++++++++++

* Monekypatch aldryn_search index to avoid errors

0.1.1 (2015-11-02)
++++++++++++++++++

* Easier extension of ApphookConfig creation

0.1.0 (2015-10-24)
++++++++++++++++++

* First experimental release
